/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.ant;

import java.io.OutputStream;
import java.io.PrintStream;

import org.tagunit.TestContextContainer;
import org.tagunit.TestContext;
import org.tagunit.TagTestContext;
import org.tagunit.taginfo.TagInfo;

/**
 * Created by IntelliJ IDEA.
 * User: sam_dalton
 * Date: Jun 2, 2003
 * Time: 9:03:46 PM
 * To change this template use Options | File Templates.
 */
public abstract class AbstractFormatter implements Formatter {
    
    /** the output stream to log the output to */
    protected PrintStream outStream = System.out;

    public abstract void displayHeader(TestContextContainer context);

    public abstract void displaySummary(TestContextContainer context);

    public abstract void displayTest(TestContext context);

    protected TagInfo getTag(TestContext context) {
        TestContext ctx = context.getParent();
        while (!(ctx instanceof TagTestContext) && (ctx != null)) {
            ctx = ctx.getParent();
        }

        if (ctx != null && ctx instanceof TagTestContext) {
            return ((TagTestContext) ctx).getTagInfo();
        } else {
            return null;
        }
    }
    
    /**
     * Sets the output stream that is to be used to handle the output.
     *
     * <P> By default, the output stream is <code> System.out </code>.  If
     * another stream is indicated here, then it is used for the output.
     *
     * @param out the output stream to be used.
     */
    public void setOutputStream(OutputStream out) {
        if ( out != null ) {
            this.outStream = new PrintStream( out, true );
        }
    }
}
