/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.ant;

import org.tagunit.*;
import org.tagunit.taginfo.TagInfo;

import java.io.OutputStream;

public class ConsoleFormatter extends AbstractFormatter {

    public void displayHeader(TestContextContainer context) {
        outStream.println("Running tests at " + context.getName());
    }

    public void displaySummary(TestContextContainer context) {

        outStream.println("Tests run: " + context.getNumberOfTests()
                + ", Failures: " + context.getNumberOfFailures()
                + ", Warnings: " + context.getNumberOfWarnings()
                + ", Errors: " + context.getNumberOfErrors()
                + ", Time elapsed: " + context.getTime());
    }

    public void displayTest(TestContext context) {
        if (context.getStatus().equals(TestContext.FAIL)
                || context.getStatus().equals(TestContext.WARNING)
                || context.getStatus().equals(TestContext.ERROR)) {

            // find the parent TagTestContext to get the tag name
            TagInfo tag = getTag(context);

            outStream.println();
            if (tag != null) {
                outStream.println(tag.getName() + " : " + context.getName());
            } else {
                outStream.println(context.getName());
            }
            //        + " took " + context.getTime() + "ms");
            outStream.println("    " + context.getStatus().getName().toUpperCase());
            outStream.println(context.getMessage());
        }
    }
}
