/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.controller;

import java.io.*;
import java.util.*;
import java.security.Principal;

import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletResponseWrapper;
import javax.servlet.http.HttpServletRequestWrapper;
import javax.servlet.http.HttpServletRequest;

/**
 * This is a simple wrapper, used to wrap up the actual ServletResponse so that
 * content never gets written to the output stream, and headers are never
 * set. This is necessary because we don't want tags actually outputting
 * content back to the browser. Instead we want to capture it, run the tests
 * and then output the results, without all of the content that would
 * otherwise be output.
 *
 * @author      Simon Brown
 */
public class TestHttpServletRequestWrapper extends HttpServletRequestWrapper {

  private String user;
  private String role;

  public TestHttpServletRequestWrapper(HttpServletRequest request) {
    super(request);
  }

  public String getRemoteUser() {
    if (this.user != null) {
      return this.user;
    } else {
      return super.getRemoteUser();
    }
  }

  public String getAuthType() {
    return super.getAuthType();
  }

  public boolean isUserInRole(String s) {
    if (this.role != null) {
      return s.equals(this.role);
    } else {
      return super.isUserInRole(s);
    }
  }

  public Principal getUserPrincipal() {
    return super.getUserPrincipal();
  }

  /**
   * Sets the user attribute.
   *
   * @param user    the name of the user
   */
  public void setUser(String user) {
    this.user = user;
  }

  /**
   * Sets the role attribute.
   *
   * @param role    the name of the role
   */
  public void setRole(String role) {
    this.role = role;
  }

}