/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.test;

import org.tagunit.TestContextContainer;
import org.tagunit.TestContext;
import org.tagunit.taginfo.TagInfo;

/**
 * Wraps up the automatic tests for a tag handler.
 *
 * @author    Simon Brown
 */
public class InterfaceTestPackage extends AbstractTagTestPackage {

  /** the interface to be tested against */
  private String type;

  /**
   * Creates a new test package for the specified tag.
   *
   * @param tagInfo   a TagInfo instance
   */
  public InterfaceTestPackage(TagInfo tagInfo, String type) {
    super(tagInfo);
    this.type = type;
  }

  /**
   * Runs the tests that are part of this test package.
   *
   * @param testContext   the TestContext to which these tests are to be run
   */
  public void executeTest(TestContextContainer testContext) {
    try {
      boolean b = (Class.forName(type).isAssignableFrom(
          Class.forName(getTagInfo().getTagHandlerClass())));
      if (b) {
        testContext.setStatus(TestContext.PASS);
      } else {
        testContext.setStatus(TestContext.FAIL);
        testContext.setMessage("Tag handler class does not implement " + type);
      }
    } catch (ClassNotFoundException cnfe) {
      testContext.setStatus(TestContext.FAIL);
      testContext.setMessage(cnfe.getMessage());
    }
  }

  /**
   * Gets the name of this test package.
   *
   * @return  the name of this test package as a String
   */
  public String getName() {
    return "Tag implements " + this.type;
  }

}