/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.test;

import org.tagunit.TestContextContainer;

/**
 * Tests that the expected content doesn't equal the actual content.
 *
 * @author    Simon Brown
 */
public class NotEqualsTestPackage extends StringComparisonTestPackage {

  /**
   * Creates a new test package for the specified tag.
   *
   * @param actualContent   the content that was generated
   * @param expectedContent   the content that was expected
   */
  public NotEqualsTestPackage(String actualContent, String expectedContent,
                              boolean ignoreWhitespace) {
    super(actualContent, expectedContent, ignoreWhitespace);
  }

  /**
   * Performs the comparison between the two pieces of text.
   *
   * @param testContext   the TestContext to which the comparison is to be run
   * @return  true if the actual content is comparable with the expected content,
   *          false otherwise
   */
  protected boolean compare(TestContextContainer testContext) {

    boolean result = false;

    if (expectedContent == null && actualContent == null) {
      result = false;
    } else if (expectedContent == null || actualContent == null) {
      result = true;
    } else {
      result = !(expectedContent.equals(actualContent));
    }

    if (!result) {
      StringBuffer message = new StringBuffer();
      message.append("Actual content of \"");
      message.append(actualContent);
      message.append("\" does equal \"");
      message.append(expectedContent);
      message.append("\"");
      testContext.setMessage(message.toString());
    }

    return result;
  }

}