/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.test;

import org.tagunit.TestContextContainer;
import org.tagunit.TestContext;

/**
 * Wraps up the automatic tests for a tag handler.
 *
 * @author    Simon Brown
 */
public class ScriptingVariableTestPackage extends AbstractTestPackage {

  private Object variable;
  private String type;
  private Object value;

  /**
   * Creates a new test package for the specified tag.
   *
   * @param variable    the scripting variable (an Object)
   * @param type        the fully qualified classname of the variable
   * @param value       the expected value of the variable
   */
  public ScriptingVariableTestPackage(Object variable, String type, Object value) {
    this.variable = variable;
    this.type = type;
    this.value = value;
  }

  /**
   * Runs the tests that are part of this test package.
   *
   * @param testContext   the TestContext to which these tests are to be run
   */
  public void executeTest(TestContextContainer testContext) {
    // first of all find the named attribute
    if (variable == null) {
      testContext.setMessage("Scripting variable named " + this.variable + " does not exist.");
      testContext.setStatus(TestContext.FAIL);

      // well the variable couldn't be found so we can't perform any more tests on it!
      return;
    }

    try {
      boolean result = (Class.forName(type).isAssignableFrom(variable.getClass()));

      if (result) {
        testContext.setStatus(TestContext.PASS);
      } else {
        testContext.setStatus(TestContext.FAIL);
        testContext.setMessage("Type of variable is " + variable.getClass());
      }
    } catch (ClassNotFoundException cnfe) {
      cnfe.printStackTrace();
    }


    // and finally check the value, using the equals() method
    if (value != null) {
      boolean result = variable.equals(value);

      if (result) {
        testContext.setStatus(TestContext.PASS);
      } else {
        testContext.setStatus(TestContext.FAIL);
        testContext.setMessage("Value of variable is " + variable);
      }
    }
  }

  /**
   * Gets the variable of this test package.
   *
   * @return  the variable of this test package as a String
   */
  public String getName() {
    return "Scripting variable (type = " + this.type + ")";
  }

}