/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.taginfo;

import junit.framework.Assert;
import junit.framework.TestCase;

/**
 * Test cases for the TagInfo class.
 *
 * @author      Simon Brown
 */
public class TagInfoTest extends TestCase {

  private TagInfo tagInfo;

  /**
   * Performs initialization before tests.
   */
  public void setUp() {
    // TagInfo is a concrete implementation, based upon
    // the TagInfo abstract class
    tagInfo = new TagInfo();
  }

  /**
   * Tests the initial values of the bean properties after construction.
   */
  public void testConstruction() {
    Assert.assertEquals(0, tagInfo.getAttributes().size());
    Assert.assertEquals(0, tagInfo.getVariables().size());
  }

  /**
   * Tests the setters and getters.
   */
  public void testSettersAndGetters() {
    tagInfo.setName("This is the name");
    Assert.assertEquals("This is the name", tagInfo.getName());

    tagInfo.setBodyContent("empty");
    Assert.assertEquals("empty", tagInfo.getBodyContent());

    tagInfo.setTagHandlerClass("taghandler.class.name");
    Assert.assertEquals("taghandler.class.name", tagInfo.getTagHandlerClass());

    tagInfo.setTagExtraInfoClass("tagextrainfo.class.name");
    Assert.assertEquals("tagextrainfo.class.name", tagInfo.getTagExtraInfoClass());

    tagInfo.setDescription("This is the description");
    Assert.assertEquals("This is the description", tagInfo.getDescription());
  }

  /**
   * Tests the ability to add and retrieve attributes.
   */
  public void testAttributes() {
    TagAttributeInfo attribute1 = new TagAttributeInfo();
    attribute1.setName("attribute1");
    tagInfo.add(attribute1);
    Assert.assertEquals(1, tagInfo.getAttributes().size());
    Assert.assertEquals(attribute1, tagInfo.getAttribute("attribute1"));

    TagAttributeInfo attribute2 = new TagAttributeInfo();
    attribute2.setName("attribute2");
    tagInfo.add(attribute2);
    Assert.assertEquals(2, tagInfo.getAttributes().size());
    Assert.assertEquals(attribute1, tagInfo.getAttribute("attribute1"));
    Assert.assertEquals(attribute2, tagInfo.getAttribute("attribute2"));
  }

  /**
   * Tests the ability to add and retrieve variables.
   */
  public void testVariables() {
    // todo
  }

}