/*
 * Copyright (c) 2002/2003, Simon Brown
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   - Neither the name of TagUnit nor the names of its contributors may
 *     be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.tagunit.test;

import junit.framework.TestCase;
import org.tagunit.DefaultTestContextContainer;

/**
 * Test cases for the EqualsTestPackage class.
 *
 * @author      Simon Brown
 */
public class NotEqualsTestPackageTest extends TestCase {

  /**
   * Tests asserting content is equal, ignoring whitespace.
   */
  public void testIgnoringWhitespace() {
    NotEqualsTestPackage testPackage = new NotEqualsTestPackage("Some content", "Some content", true);
    DefaultTestContextContainer context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    testPackage = new NotEqualsTestPackage("  Some content  ", "Some content", true);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    testPackage = new NotEqualsTestPackage("Some content", "  Some content  ", true);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    testPackage = new NotEqualsTestPackage("  Some \n content  ", "Some content\n", true);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    testPackage = new NotEqualsTestPackage("Some content", "Some other content", true);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());
  }

  /**
   * Tests asserting content is equal, not ignoring whitespace.
   */
  public void testNotIgnoringWhitespace() {
    NotEqualsTestPackage testPackage = new NotEqualsTestPackage("Some content", "Some content", false);
    DefaultTestContextContainer context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    testPackage = new NotEqualsTestPackage("  Some content  ", "Some content", false);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    testPackage = new NotEqualsTestPackage("Some content", "  Some content  ", false);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    testPackage = new NotEqualsTestPackage("Some content", "Some other content", false);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());
  }

  /**
   * Tests asserting null and empty content.
   */
  public void testNullAndEmptyContent() {
    NotEqualsTestPackage testPackage = new NotEqualsTestPackage(null, "", true);
    DefaultTestContextContainer context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    testPackage = new NotEqualsTestPackage("", null, true);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    testPackage = new NotEqualsTestPackage(null, null, true);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    testPackage = new NotEqualsTestPackage("", "", true);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    testPackage = new NotEqualsTestPackage(null, "", false);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    testPackage = new NotEqualsTestPackage("", null, false);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(true, context.getResult());

    testPackage = new NotEqualsTestPackage(null, null, false);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());

    testPackage = new NotEqualsTestPackage("", "", false);
    context = new DefaultTestContextContainer();
    testPackage.executeTest(context);
    assertEquals(false, context.getResult());
  }

}